threading — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- core »

# threading

Some helper functions and classes related to threading issues

`camelot.core.threading.` `synchronized`(original_function)

  Decorator for synchronized access to an object, the object should have an attribute _mutex which is of type QMutex

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- core »

Comments
blog comments powered by Disqus